@@ -36,6 +36,12 @@
 #include "cd-interp-akima.h"
 #include "cd-interp-linear.h"
 
+/* this is private */
+struct _CdColorSwatch {
+	gchar		*name;
+	CdColorLab	 value;
+};
+
 /**
  * cd_color_xyz_dup:
  *
@@ -70,6 +76,23 @@ cd_color_rgb_dup (const CdColorRGB *src)
 	return dest;
 }
 
+/**
+ * cd_color_lab_dup:
+ *
+ * Since: 0.1.32
+ **/
+CdColorLab *
+cd_color_lab_dup (const CdColorLab *src)
+{
+	CdColorLab *dest;
+	g_return_val_if_fail (src != NULL, NULL);
+	dest = cd_color_lab_new ();
+	dest->L = src->L;
+	dest->a = src->a;
+	dest->b = src->b;
+	return dest;
+}
+
 /**
  * cd_color_yxy_dup:
  *
@@ -81,11 +104,52 @@ cd_color_yxy_dup (const CdColorYxy *src)
 	CdColorYxy *dest;
 	g_return_val_if_fail (src != NULL, NULL);
 	dest = cd_color_yxy_new ();
+	dest->Y = src->Y;
 	dest->x = src->x;
 	dest->y = src->y;
 	return dest;
 }
 
+/**
+ * cd_color_swatch_dup:
+ *
+ * Since: 0.1.32
+ **/
+CdColorSwatch *
+cd_color_swatch_dup (const CdColorSwatch *src)
+{
+	CdColorSwatch *dest;
+	g_return_val_if_fail (src != NULL, NULL);
+	dest = cd_color_swatch_new ();
+	dest->name = g_strdup (src->name);
+	cd_color_lab_copy (&src->value, &dest->value);
+	return dest;
+}
+
+/**
+ * cd_color_swatch_get_name:
+ *
+ * Since: 0.1.32
+ **/
+const gchar *
+cd_color_swatch_get_name (const CdColorSwatch *swatch)
+{
+	g_return_val_if_fail (swatch != NULL, NULL);
+	return swatch->name;
+}
+
+/**
+ * cd_color_swatch_get_value:
+ *
+ * Since: 0.1.32
+ **/
+const CdColorLab *
+cd_color_swatch_get_value (const CdColorSwatch *swatch)
+{
+	g_return_val_if_fail (swatch != NULL, NULL);
+	return &swatch->value;
+}
+
 /**
  * cd_color_xyz_get_type:
  *
@@ -126,6 +190,26 @@ cd_color_rgb_get_type (void)
 	return type_id;
 }
 
+/**
+ * cd_color_lab_get_type:
+ *
+ * Gets a specific type.
+ *
+ * Return value: a #GType
+ *
+ * Since: 0.1.32
+ **/
+GType
+cd_color_lab_get_type (void)
+{
+	static GType type_id = 0;
+	if (!type_id)
+		type_id = g_boxed_type_register_static ("CdColorLab",
+							(GBoxedCopyFunc) cd_color_lab_dup,
+							(GBoxedFreeFunc) cd_color_lab_free);
+	return type_id;
+}
+
 /**
  * cd_color_yxy_get_type:
  *
@@ -146,6 +230,26 @@ cd_color_yxy_get_type (void)
 	return type_id;
 }
 
+/**
+ * cd_color_swatch_get_type:
+ *
+ * Gets a specific type.
+ *
+ * Return value: a #GType
+ *
+ * Since: 0.1.32
+ **/
+GType
+cd_color_swatch_get_type (void)
+{
+	static GType type_id = 0;
+	if (!type_id)
+		type_id = g_boxed_type_register_static ("CdColorSwatch",
+							(GBoxedCopyFunc) cd_color_swatch_dup,
+							(GBoxedFreeFunc) cd_color_swatch_free);
+	return type_id;
+}
+
 /**
  * cd_color_xyz_new:
  *
@@ -184,6 +288,21 @@ cd_color_rgb_new (void)
 #endif
 }
 
+/**
+ * cd_color_lab_new:
+ *
+ * Allocates a color value.
+ *
+ * Return value: A newly allocated #CdColorLab object
+ *
+ * Since: 0.1.32
+ **/
+CdColorLab *
+cd_color_lab_new (void)
+{
+	return g_slice_new0 (CdColorLab);
+}
+
 /**
  * cd_color_yxy_new:
  *
@@ -203,6 +322,21 @@ cd_color_yxy_new (void)
 #endif
 }
 
+/**
+ * cd_color_swatch_new:
+ *
+ * Allocates a color value.
+ *
+ * Return value: A newly allocated #CdColorYxy object
+ *
+ * Since: 0.1.32
+ **/
+CdColorSwatch *
+cd_color_swatch_new (void)
+{
+	return g_slice_new0 (CdColorSwatch);
+}
+
 /**
  * cd_color_xyz_free:
  * @src: the color object
@@ -239,6 +373,20 @@ cd_color_rgb_free (CdColorRGB *src)
 #endif
 }
 
+/**
+ * cd_color_lab_free:
+ * @src: the color object
+ *
+ * Deallocates a color value.
+ *
+ * Since: 0.1.32
+ **/
+void
+cd_color_lab_free (CdColorLab *src)
+{
+	g_slice_free (CdColorLab, src);
+}
+
 /**
  * cd_color_yxy_free:
  * @src: the color object
@@ -257,6 +405,21 @@ cd_color_yxy_free (CdColorYxy *src)
 #endif
 }
 
+/**
+ * cd_color_swatch_free:
+ * @src: the color object
+ *
+ * Deallocates a color swatch.
+ *
+ * Since: 0.1.32
+ **/
+void
+cd_color_swatch_free (CdColorSwatch *src)
+{
+	g_free (src->name);
+	g_slice_free (CdColorSwatch, src);
+}
+
 /**
  * cd_color_xyz_set:
  * @dest: the destination color
@@ -317,6 +480,27 @@ cd_color_rgb_set (CdColorRGB *dest, gdouble R, gdouble G, gdouble B)
 	dest->B = B;
 }
 
+/**
+ * cd_color_lab_set:
+ * @dest: the destination color
+ * @L: component value
+ * @a: component value
+ * @b: component value
+ *
+ * Initialises a color value.
+ *
+ * Since: 0.1.32
+ **/
+void
+cd_color_lab_set (CdColorLab *dest, gdouble L, gdouble a, gdouble b)
+{
+	g_return_if_fail (dest != NULL);
+
+	dest->L = L;
+	dest->a = a;
+	dest->b = b;
+}
+
 /**
  * cd_color_yxy_set:
  * @dest: the destination color
@@ -338,6 +522,41 @@ cd_color_yxy_set (CdColorYxy *dest, gdouble Y, gdouble x, gdouble y)
 	dest->y = y;
 }
 
+/**
+ * cd_color_swatch_set_name:
+ * @dest: the destination swatch
+ * @name: component name
+ *
+ * Initialises a swatch name.
+ *
+ * Since: 0.1.32
+ **/
+void
+cd_color_swatch_set_name (CdColorSwatch *dest, const gchar *name)
+{
+	g_return_if_fail (dest != NULL);
+	g_return_if_fail (name != NULL);
+	g_free (dest->name);
+	dest->name = g_strdup (name);
+}
+
+/**
+ * cd_color_swatch_set_value:
+ * @dest: the destination swatch
+ * @value: component value
+ *
+ * Initialises a swatch value.
+ *
+ * Since: 0.1.32
+ **/
+void
+cd_color_swatch_set_value (CdColorSwatch *dest, const CdColorLab *value)
+{
+	g_return_if_fail (dest != NULL);
+	g_return_if_fail (value != NULL);
+	cd_color_lab_copy (value, &dest->value);
+}
+
 /**
  * cd_color_xyz_copy:
  * @src: the source color
@@ -378,6 +597,26 @@ cd_color_yxy_copy (const CdColorYxy *src, CdColorYxy *dest)
 	dest->y = src->y;
 }
 
+/**
+ * cd_color_lab_copy:
+ * @src: the source color
+ * @dest: the destination color
+ *
+ * Deep copies a color value.
+ *
+ * Since: 0.1.32
+ **/
+void
+cd_color_lab_copy (const CdColorLab *src, CdColorLab *dest)
+{
+	g_return_if_fail (src != NULL);
+	g_return_if_fail (dest != NULL);
+
+	dest->L = src->L;
+	dest->a = src->a;
+	dest->b = src->b;
+}
+
 /**
  * cd_color_rgb_copy:
  * @src: the source color
